---
name: g.gui
description: Launches a GRASS graphical user interface (GUI) session. Optionally updates default user interface settings.
keywords: [ general, GUI, user interface ]
---

# g.gui

Launches a GRASS graphical user interface (GUI) session.

Optionally updates default user interface settings.

=== "Command line"

    **g.gui**
    [**-fdn**]
    [**ui**=*string*]
    [**workspace**=*name.gxw*]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    g.gui
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***g.gui***",
        **ui**=*"wxpython"*,
        **workspace**=*None*,
        **flags**=*None*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("g.gui")
    ```

## Parameters

=== "Command line"

    **ui**=*string*  
    &nbsp;&nbsp;&nbsp;&nbsp;User interface  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *wxpython, text, gtext*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *wxpython*  
    &nbsp;&nbsp;&nbsp;&nbsp;**wxpython**: wxPython based GUI (wxGUI)  
    &nbsp;&nbsp;&nbsp;&nbsp;**text**: command line interface only  
    &nbsp;&nbsp;&nbsp;&nbsp;**gtext**: command line interface with GUI startup screen  
    **workspace**=*name.gxw*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of workspace file to load on start-up  
    &nbsp;&nbsp;&nbsp;&nbsp;This is valid only for wxGUI (wxpython)  
    **-f**  
    &nbsp;&nbsp;&nbsp;&nbsp;Start GUI in the foreground  
    &nbsp;&nbsp;&nbsp;&nbsp;By default the GUI starts in the background and control is immediately returned to the caller. When GUI runs in foregreound, it blocks the command line  
    **-d**  
    &nbsp;&nbsp;&nbsp;&nbsp;Update default user interface settings  
    **-n**  
    &nbsp;&nbsp;&nbsp;&nbsp;Do not launch GUI after updating the default user interface settings  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **ui** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;User interface  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *wxpython, text, gtext*  
    &nbsp;&nbsp;&nbsp;&nbsp;**wxpython**: wxPython based GUI (wxGUI)  
    &nbsp;&nbsp;&nbsp;&nbsp;**text**: command line interface only  
    &nbsp;&nbsp;&nbsp;&nbsp;**gtext**: command line interface with GUI startup screen  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *wxpython*  
    **workspace** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of workspace file to load on start-up  
    &nbsp;&nbsp;&nbsp;&nbsp;This is valid only for wxGUI (wxpython)  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, file, *name.gxw*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *f*, *d*, *n*  
    &nbsp;&nbsp;&nbsp;&nbsp;**f**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Start GUI in the foreground  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;By default the GUI starts in the background and control is immediately returned to the caller. When GUI runs in foregreound, it blocks the command line  
    &nbsp;&nbsp;&nbsp;&nbsp;**d**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Update default user interface settings  
    &nbsp;&nbsp;&nbsp;&nbsp;**n**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Do not launch GUI after updating the default user interface settings  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

The *g.gui* module allows user to start the Graphical User Interface
(GUI) from the command line prompt or to change the default User
Interface (UI) settings.

GRASS GIS comes with both a wxPython-based GUI aka *[wxGUI](wxGUI.md)*
(**ui=wxpython**) and command line text-based UI (**ui=text**).

## NOTES

If the **-d** update flag is given or the `GRASS_GUI` environmental
[variable](variables.md) is unset, then the GRASS internal variable
`GUI` is permanently changed and the selected **ui** will be used as the
default UI from then on.

All GRASS internal variables (see *[g.gisenv](g.gisenv.md)*) are stored
in the user's home directory in a hidden file called `$HOME/.grass8/rc`
on Unix-based operating systems and `%APPDATA%\GRASS8\rc` on MS Windows.
Note that these GRASS internal variables are not the shell environment
variables and the `rc` file is not a classic UNIX run command file, it
just contains persistent GRASS variables.

## EXAMPLES

### Set default user interface settings

Set default user interface setting to command line, text-based UI:

```sh
g.gui -d ui=text
```

Set default user interface setting to the graphical user interface (GUI)
and *launch* the GUI:

```sh
g.gui -d ui=wxpython
```

Set default user interface setting to the graphical user interface (GUI)
but *do not launch* the GUI:

```sh
g.gui -dn ui=wxpython
```

### Load workspace from command line

Start the GUI from command line with an existing workspace:

```sh
g.gui workspace=myproject.gxw
```

## SEE ALSO

*[wxGUI](wxGUI.md), [g.gisenv](g.gisenv.md), [GRASS
variables](variables.md)*

[wxGUI wiki
page](https://grasswiki.osgeo.org/wiki/WxPython-based_GUI_for_GRASS)

## AUTHORS

Martin Landa, FBK-irst, Trento, Italy  
Hamish Bowman, Otago University, Dunedin, New Zealand (fine tuning)

## SOURCE CODE

Available at: [g.gui source code](https://github.com/OSGeo/grass/tree/main/general/g.gui)
([history](https://github.com/OSGeo/grass/commits/main/general/g.gui))  
Latest change: Thursday May 08 14:35:40 2025 in commit [9528b1e](https://github.com/OSGeo/grass/commit/9528b1e38ba37992c1597a979dc3efbb07b74ec5)
