---
name: r.latlong
description: Creates a latitude/longitude raster map.
keywords: [ raster, latitude, longitude, projection ]
---

# r.latlong

Creates a latitude/longitude raster map.

=== "Command line"

    **r.latlong**
    [**-l**]
    **input**=*name*
    **output**=*name*
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r.latlong input=name output=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***r.latlong***",
        **input**,
        **output**,
        **flags**=*None*,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("r.latlong", input="name", output="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
    **output**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output latitude or longitude raster map  
    **-l**  
    &nbsp;&nbsp;&nbsp;&nbsp;Longitude output  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, raster, *name*  
    **output** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output latitude or longitude raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, raster, *name*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *l*  
    &nbsp;&nbsp;&nbsp;&nbsp;**l**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Longitude output  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*r.latlong* creates a latitude (degree decimal) map, or longitude if the
-l flag is used, from any map in any projection using PROJ library. This
is an input to *r.sun* and *i.evapo.potrad*.

## NOTES

The PROJ [website](https://proj.org).

## TODO

Datum transform is not implemented, the same datum is taken as output.

## EXAMPLE

```sh
g.region raster=elevation -p
r.latlong input=elevation output=latitude
```

## SEE ALSO

*[r.sun](r.sun.md), [r.sunhours](r.sunhours.md)*

## AUTHOR

Yann Chemin, International Rice Research Institute, The Philippines

## SOURCE CODE

Available at: [r.latlong source code](https://github.com/OSGeo/grass/tree/main/raster/r.latlong)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.latlong))  
Latest change: Wednesday May 07 11:53:32 2025 in commit [73e7b2f](https://github.com/OSGeo/grass/commit/73e7b2f28754298331e7ceaa5eaa83c8854fe1e1)
